@@ -1,7 +1,7 @@
 package App::ScreensaverUtils;
 
-our $DATE = '2019-04-30'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $DATE = '2019-09-03'; # DATE
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict;
@@ -40,6 +40,37 @@ sub prevent_screensaver_activated_while {
     [200, "Exit code is $exit", "", {"cmdline.exit_code"=>$exit}];
 }
 
+$SPEC{prevent_screensaver_activated_until_interrupted} = {
+    v => 1.1,
+    summary => 'Prevent screensaver activated until interrupted',
+    description => <<'_',
+
+Uses <pm:Proc::Govern> to run `sleep infinity`. To stop preventing screensaver
+from sleeping, press Ctrl-C.
+
+For more options when running command, e.g. timeout, load control, autorestart,
+use the module or its CLI <prog:govproc> instead.
+
+Available in CLI with two shorter aliases: <prog:pause-screensaver> and
+<prog:noss>.
+
+_
+    args => {
+    },
+};
+sub prevent_screensaver_activated_until_interrupted {
+    require Proc::Govern;
+
+    my %args = @_;
+
+    my $exit = Proc::Govern::govern_process(
+        command => ['sleep', 'infinity'],
+        no_screensaver => 1,
+    );
+
+    [200, "Exit code is $exit", "", {"cmdline.exit_code"=>$exit}];
+}
+
 1;
 # ABSTRACT: CLI utilities related to screensaver
 
@@ -55,7 +86,7 @@ App::ScreensaverUtils - CLI utilities related to screensaver
 
 =head1 VERSION
 
-This document describes version 0.004 of App::ScreensaverUtils (from Perl distribution App-ScreensaverUtils), released on 2019-04-30.
+This document describes version 0.005 of App::ScreensaverUtils (from Perl distribution App-ScreensaverUtils), released on 2019-09-03.
 
 =head1 DESCRIPTION
 
@@ -75,8 +106,14 @@ This distribution contains the following CLI utilities related to screensaver:
 
 =item * L<get-screensaver-timeout>
 
+=item * L<noss>
+
+=item * L<pause-screensaver>
+
 =item * L<prevent-screensaver-activated>
 
+=item * L<prevent-screensaver-activated-until-interrupted>
+
 =item * L<prevent-screensaver-activated-while>
 
 =item * L<screensaver-is-active>
@@ -88,6 +125,40 @@ This distribution contains the following CLI utilities related to screensaver:
 =head1 FUNCTIONS
 
 
+=head2 prevent_screensaver_activated_until_interrupted
+
+Usage:
+
+ prevent_screensaver_activated_until_interrupted() -> [status, msg, payload, meta]
+
+Prevent screensaver activated until interrupted.
+
+Uses L<Proc::Govern> to run C<sleep infinity>. To stop preventing screensaver
+from sleeping, press Ctrl-C.
+
+For more options when running command, e.g. timeout, load control, autorestart,
+use the module or its CLI L<govproc> instead.
+
+Available in CLI with two shorter aliases: L<pause-screensaver> and
+L<noss>.
+
+This function is not exported.
+
+No arguments.
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (payload) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
+
 =head2 prevent_screensaver_activated_while
 
 Usage:
